==> xlniuxdata-vipgame-1.0.58-sources.jar: com/xunlei/niux/data/vipgame/vo/vic/PersonInfo.java <==
package com.xunlei.niux.data.vipgame.vo.vic;

import com.ferret.common.dao.annotation.Table;

@Table(tableName="vic_person_info",pkFieldName="seqid",pkFieldAssign=false)
public class PersonInfo {
    private Long seqid;
    private Long uid;
    private String realName;
    private String mobileNumber;
    private String qqNumber;
    private String sex;
    private Integer age;
    private String birthday;
    private String address;
    private String degree;
    private String job;
    private String annualSalary;
    private String placeProvince;
    private String placeCity;
    private String family;
    private String lostLogin;
    private String lostPay;
    private String firstTreat;
    private String firstTreatResult;
    private String secondTreat;
    private String secondTreatResult;
    private String firstTreatLogin;
    private String firstTreatResultLogin;
    private String secondTreatLogin;
    private String secondTreatResultLogin;


    //新增
    private String nativePlaceProvice;
    private String nativePlaceCity;
    private String familyGroup;
    private Integer married;
    private String gameType;
    private String interest;
    private Integer gameFrequency;
    private Integer netAge;
    private Integer gameAge;
    private Integer pcBandwidth;
    private Integer pcAddr;
    private Integer mobileBandwidth;
    private Integer mobileAddr;


    public String getFirstTreatLogin() {
        return firstTreatLogin;
    }

    public void setFirstTreatLogin(String firstTreatLogin) {
        this.firstTreatLogin = firstTreatLogin;
    }

    public String getFirstTreatResultLogin() {
        return firstTreatResultLogin;
    }

    public void setFirstTreatResultLogin(String firstTreatResultLogin) {
        this.firstTreatResultLogin = firstTreatResultLogin;
    }

    public String getSecondTreatLogin() {
        return secondTreatLogin;
    }

    public void setSecondTreatLogin(String secondTreatLogin) {
        this.secondTreatLogin = secondTreatLogin;
    }

    public String getSecondTreatResultLogin() {
        return secondTreatResultLogin;
    }

    public void setSecondTreatResultLogin(String secondTreatResultLogin) {
        this.secondTreatResultLogin = secondTreatResultLogin;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public Integer getAge() {
        return age;
    }

    public void setAge(Integer age) {
        this.age = age;
    }

    public String getAnnualSalary() {
        return annualSalary;
    }

    public void setAnnualSalary(String annualSalary) {
        this.annualSalary = annualSalary;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getDegree() {
        return degree;
    }

    public void setDegree(String degree) {
        this.degree = degree;
    }

    public String getFamily() {
        return family;
    }

    public void setFamily(String family) {
        this.family = family;
    }

    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }

    public String getLostLogin() {
        return lostLogin;
    }

    public void setLostLogin(String lostLogin) {
        this.lostLogin = lostLogin;
    }

    public String getLostPay() {
        return lostPay;
    }

    public void setLostPay(String lostPay) {
        this.lostPay = lostPay;
    }

    public String getMobileNumber() {
        return mobileNumber;
    }

    public void setMobileNumber(String mobileNumber) {
        this.mobileNumber = mobileNumber;
    }

    public String getPlaceCity() {
        return placeCity;
    }

    public void setPlaceCity(String placeCity) {
        this.placeCity = placeCity;
    }

    public String getPlaceProvince() {
        return placeProvince;
    }

    public void setPlaceProvince(String placeProvince) {
        this.placeProvince = placeProvince;
    }

    public String getQqNumber() {
        return qqNumber;
    }

    public void setQqNumber(String qqNumber) {
        this.qqNumber = qqNumber;
    }

    public String getRealName() {
        return realName;
    }

    public void setRealName(String realName) {
        this.realName = realName;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public String getSex() {
        return sex;
    }

    public void setSex(String sex) {
        this.sex = sex;
    }

    public Long getUid() {
        return uid;
    }

    public void setUid(Long uid) {
        this.uid = uid;
    }

    public String getFirstTreat() {
        return firstTreat;
    }

    public void setFirstTreat(String firstTreat) {
        this.firstTreat = firstTreat;
    }

    public String getFirstTreatResult() {
        return firstTreatResult;
    }

    public void setFirstTreatResult(String firstTreatResult) {
        this.firstTreatResult = firstTreatResult;
    }

    public String getSecondTreat() {
        return secondTreat;
    }

    public void setSecondTreat(String secondTreat) {
        this.secondTreat = secondTreat;
    }

    public String getSecondTreatResult() {
        return secondTreatResult;
    }

    public void setSecondTreatResult(String secondTreatResult) {
        this.secondTreatResult = secondTreatResult;
    }


    public String getNativePlaceProvice() {
        return nativePlaceProvice;
    }

    public void setNativePlaceProvice(String nativePlaceProvice) {
        this.nativePlaceProvice = nativePlaceProvice;
    }

    public String getNativePlaceCity() {
        return nativePlaceCity;
    }

    public void setNativePlaceCity(String nativePlaceCity) {
        this.nativePlaceCity = nativePlaceCity;
    }

    public String getFamilyGroup() {
        return familyGroup;
    }

    public void setFamilyGroup(String familyGroup) {
        this.familyGroup = familyGroup;
    }

    public Integer getMarried() {
        return married;
    }

    public void setMarried(Integer married) {
        this.married = married;
    }

    public String getGameType() {
        return gameType;
    }

    public void setGameType(String gameType) {
        this.gameType = gameType;
    }

    public String getInterest() {
        return interest;
    }

    public void setInterest(String interest) {
        this.interest = interest;
    }

    public Integer getGameFrequency() {
        return gameFrequency;
    }

    public void setGameFrequency(Integer gameFrequency) {
        this.gameFrequency = gameFrequency;
    }

    public Integer getNetAge() {
        return netAge;
    }

    public void setNetAge(Integer netAge) {
        this.netAge = netAge;
    }

    public Integer getGameAge() {
        return gameAge;
    }

    public void setGameAge(Integer gameAge) {
        this.gameAge = gameAge;
    }

    public Integer getPcBandwidth() {
        return pcBandwidth;
    }

    public void setPcBandwidth(Integer pcBandwidth) {
        this.pcBandwidth = pcBandwidth;
    }

    public Integer getPcAddr() {
        return pcAddr;
    }

    public void setPcAddr(Integer pcAddr) {
        this.pcAddr = pcAddr;
    }

    public Integer getMobileBandwidth() {
        return mobileBandwidth;
    }

    public void setMobileBandwidth(Integer mobileBandwidth) {
        this.mobileBandwidth = mobileBandwidth;
    }

    public Integer getMobileAddr() {
        return mobileAddr;
    }

    public void setMobileAddr(Integer mobileAddr) {
        this.mobileAddr = mobileAddr;
    }
}

==> xlniuxdata-vipgame-1.0.60-20160516.090641-2-sources.jar: com/xunlei/niux/data/vipgame/vo/vic/PersonInfo.java <==
package com.xunlei.niux.data.vipgame.vo.vic;

import com.ferret.common.dao.annotation.Table;

@Table(tableName="vic_person_info",pkFieldName="seqid",pkFieldAssign=false)
public class PersonInfo {
    private Long seqid;
    private Long uid;
    private String realName;
    private String mobileNumber;
    private String qqNumber;
    private String sex;
    private Integer age;
    private String birthday;
    private String address;
    private String degree;
    private String job;
    private String annualSalary;
    private String placeProvince;
    private String placeCity;
    private String placeTown;
    private String family;
    private String lostLogin;
    private String lostPay;
    private String firstTreat;
    private String firstTreatResult;
    private String secondTreat;
    private String secondTreatResult;
    private String firstTreatLogin;
    private String firstTreatResultLogin;
    private String secondTreatLogin;
    private String secondTreatResultLogin;


    //新增
    private String nativePlaceProvice;
    private String nativePlaceCity;
    private String familyGroup;
    private Integer married;
    private String gameType;
    private String interest;
    private Integer gameFrequency;
    private Integer netAge;
    private Integer gameAge;
    private Integer pcBandwidth;
    private Integer pcAddr;
    private Integer mobileBandwidth;
    private Integer mobileAddr;

    public String getPlaceTown() {
        return placeTown;
    }

    public void setPlaceTown(String placeTown) {
        this.placeTown = placeTown;
    }

    public String getFirstTreatLogin() {
        return firstTreatLogin;
    }

    public void setFirstTreatLogin(String firstTreatLogin) {
        this.firstTreatLogin = firstTreatLogin;
    }

    public String getFirstTreatResultLogin() {
        return firstTreatResultLogin;
    }

    public void setFirstTreatResultLogin(String firstTreatResultLogin) {
        this.firstTreatResultLogin = firstTreatResultLogin;
    }

    public String getSecondTreatLogin() {
        return secondTreatLogin;
    }

    public void setSecondTreatLogin(String secondTreatLogin) {
        this.secondTreatLogin = secondTreatLogin;
    }

    public String getSecondTreatResultLogin() {
        return secondTreatResultLogin;
    }

    public void setSecondTreatResultLogin(String secondTreatResultLogin) {
        this.secondTreatResultLogin = secondTreatResultLogin;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public Integer getAge() {
        return age;
    }

    public void setAge(Integer age) {
        this.age = age;
    }

    public String getAnnualSalary() {
        return annualSalary;
    }

    public void setAnnualSalary(String annualSalary) {
        this.annualSalary = annualSalary;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getDegree() {
        return degree;
    }

    public void setDegree(String degree) {
        this.degree = degree;
    }

    public String getFamily() {
        return family;
    }

    public void setFamily(String family) {
        this.family = family;
    }

    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }

    public String getLostLogin() {
        return lostLogin;
    }

    public void setLostLogin(String lostLogin) {
        this.lostLogin = lostLogin;
    }

    public String getLostPay() {
        return lostPay;
    }

    public void setLostPay(String lostPay) {
        this.lostPay = lostPay;
    }

    public String getMobileNumber() {
        return mobileNumber;
    }

    public void setMobileNumber(String mobileNumber) {
        this.mobileNumber = mobileNumber;
    }

    public String getPlaceCity() {
        return placeCity;
    }

    public void setPlaceCity(String placeCity) {
        this.placeCity = placeCity;
    }

    public String getPlaceProvince() {
        return placeProvince;
    }

    public void setPlaceProvince(String placeProvince) {
        this.placeProvince = placeProvince;
    }

    public String getQqNumber() {
        return qqNumber;
    }

    public void setQqNumber(String qqNumber) {
        this.qqNumber = qqNumber;
    }

    public String getRealName() {
        return realName;
    }

    public void setRealName(String realName) {
        this.realName = realName;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public String getSex() {
        return sex;
    }

    public void setSex(String sex) {
        this.sex = sex;
    }

    public Long getUid() {
        return uid;
    }

    public void setUid(Long uid) {
        this.uid = uid;
    }

    public String getFirstTreat() {
        return firstTreat;
    }

    public void setFirstTreat(String firstTreat) {
        this.firstTreat = firstTreat;
    }

    public String getFirstTreatResult() {
        return firstTreatResult;
    }

    public void setFirstTreatResult(String firstTreatResult) {
        this.firstTreatResult = firstTreatResult;
    }

    public String getSecondTreat() {
        return secondTreat;
    }

    public void setSecondTreat(String secondTreat) {
        this.secondTreat = secondTreat;
    }

    public String getSecondTreatResult() {
        return secondTreatResult;
    }

    public void setSecondTreatResult(String secondTreatResult) {
        this.secondTreatResult = secondTreatResult;
    }


    public String getNativePlaceProvice() {
        return nativePlaceProvice;
    }

    public void setNativePlaceProvice(String nativePlaceProvice) {
        this.nativePlaceProvice = nativePlaceProvice;
    }

    public String getNativePlaceCity() {
        return nativePlaceCity;
    }

    public void setNativePlaceCity(String nativePlaceCity) {
        this.nativePlaceCity = nativePlaceCity;
    }

    public String getFamilyGroup() {
        return familyGroup;
    }

    public void setFamilyGroup(String familyGroup) {
        this.familyGroup = familyGroup;
    }

    public Integer getMarried() {
        return married;
    }

    public void setMarried(Integer married) {
        this.married = married;
    }

    public String getGameType() {
        return gameType;
    }

    public void setGameType(String gameType) {
        this.gameType = gameType;
    }

    public String getInterest() {
        return interest;
    }

    public void setInterest(String interest) {
        this.interest = interest;
    }

    public Integer getGameFrequency() {
        return gameFrequency;
    }

    public void setGameFrequency(Integer gameFrequency) {
        this.gameFrequency = gameFrequency;
    }

    public Integer getNetAge() {
        return netAge;
    }

    public void setNetAge(Integer netAge) {
        this.netAge = netAge;
    }

    public Integer getGameAge() {
        return gameAge;
    }

    public void setGameAge(Integer gameAge) {
        this.gameAge = gameAge;
    }

    public Integer getPcBandwidth() {
        return pcBandwidth;
    }

    public void setPcBandwidth(Integer pcBandwidth) {
        this.pcBandwidth = pcBandwidth;
    }

    public Integer getPcAddr() {
        return pcAddr;
    }

    public void setPcAddr(Integer pcAddr) {
        this.pcAddr = pcAddr;
    }

    public Integer getMobileBandwidth() {
        return mobileBandwidth;
    }

    public void setMobileBandwidth(Integer mobileBandwidth) {
        this.mobileBandwidth = mobileBandwidth;
    }

    public Integer getMobileAddr() {
        return mobileAddr;
    }

    public void setMobileAddr(Integer mobileAddr) {
        this.mobileAddr = mobileAddr;
    }
}
